Affine arithmetic (verry.affineform)#

This module provides affine arithmetic.

Affine form#

AffineForm(value)

Affine form.

summarize(vars, n[, m])

In-place version of summarized().

summarized(vars, n[, m])

Reduce the number of noise symbols while keeping correlation between vars.

Context#

Context([rounding])

Create a new context.

getcontext()

Return the current context for the active thread.

localcontext([ctx, rounding])

Return a context manager.

setcontext(ctx)

Set the current context for the active thread to ctx.