Automatic differentiation (verry.autodiff)#

This module provides forward-mode automatic differentiation.

Differential operators#

deriv(fun)

Return a function that evaluates the derivative of the univariate scalar-valued function.

grad(fun)

Return a function that evaluates the gradient of the multivariate scalar-valued function.

jacobian(fun)

Return a function that evaluates the Jacobian matrix of the multivariate vector-valued function.

Number systems containing infinitesimals#

Dual(real, imag)

Abstract base class for dual numbers.

Jet(coeffs)

Abstract base class for jets.

DynDual(real, imag)

Dual for an arbitrary coefficient type.

DynJet(coeffs)

Jet for an arbitrary coefficient type.

IntervalDual(real, imag)

Dual with interval coefficients.

IntervalJet(coeffs)

Jet with interval coefficients.