Affine arithmetic (verry.affineform)#
This module provides affine arithmetic.
Affine form#
|
Affine form. |
|
In-place version of |
|
Reduce the number of noise symbols while keeping correlation between vars. |
Context#
|
Create a new context. |
Return the current context for the active thread. |
|
|
Return a context manager. |
|
Set the current context for the active thread to ctx. |