Automatic differentiation (verry.autodiff)#
This module provides forward-mode automatic differentiation.
Differential operators#
|
Return a function that evaluates the derivative of the univariate scalar-valued function. |
|
Return a function that evaluates the gradient of the multivariate scalar-valued function. |
|
Return a function that evaluates the Jacobian matrix of the multivariate vector-valued function. |
Number systems containing infinitesimals#
|
Abstract base class for dual numbers. |
|
Abstract base class for jets. |
|
Dual for an arbitrary coefficient type. |
|
Jet for an arbitrary coefficient type. |
|
Dual with interval coefficients. |
|
Jet with interval coefficients. |